<?php

require_once 'autoload.php';
require_once 'Symfony/Bundle/FrameworkBundle/autoload.php';
require_once 'Symfony/Component/Security/Acl/autoload.php';
// require_once 'Predis/Autoloader.php';
// Predis\Autoloader::register();

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___,
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    true,
    false
);
// @codeCoverageIgnoreEnd
